==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/ru.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Тёмное оформление",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Тёмное оформление снижает напряжение глаз за счёт уменьшения общей яркости. Тема находится в разработке. Сообщайте о всех найденных ошибках и недочётах.",
    "High contrast mode" : "Высококонтрастный режим",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Этот высококонтрастный режим упрощает навигацию по сайту. Качество изображения будет уменьшено за счёт увеличения чёткости.",
    "Dyslexia font" : "Шрифт Dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic — бесплатный шрифт, который смягчает некоторые распространённые ошибки чтения, вызываемые дислексией.",
    "Accessibility" : "Удобство",
    "Accessibility options for nextcloud" : "Настройки удобства для Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Предоставляет расширенный вариант настройки nextcloud, для более комфортного использования",
    "Web Content Accessibility Guidelines" : "Руководство по обеспечению доступности Web-контента WGAG",
    "our issue tracker" : "Сообщить об ошибке",
    "our design team" : "Команда разработчиков",
    "Enable" : "Включить",
    "High contrast theme" : "Высококонтрастное оформление",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Это высококонтрастное оформление упрощает навигацию по сайту. Качество изображения будет уменьшено за счёт увеличения чёткости.",
    "Dark theme (beta)" : "Тёмное оформление (бета)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic — это бесплатный шрифт, разработанный для облегчения восприятия текста людьми, которые страдают дислексией. Шрифт был создан Абелардо Гонсалесом (ориг. Abelardo Gonzalez), на правах лицензии с открытым исходным кодом (SIL Open Font License).",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Предоставляет расширенный вариант настройки nextcloud, для более комфортного использования",
    "Themes" : "Оформления",
    "Fonts" : "Шрифты",
    "enabled" : "Задействован"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/ru.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Тёмная тема",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Тёмное оформление снижает напряжение глаз за счёт уменьшения общей яркости. Тема находится в разработке. Сообщайте о всех найденных ошибках и недочётах.",
    "High contrast mode" : "Режим высокой контрастности",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Этот высококонтрастный режим упрощает навигацию по сайту. Качество изображения будет уменьшено за счёт увеличения чёткости.",
    "Dyslexia font" : "Шрифт Dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic — бесплатный шрифт, который смягчает некоторые распространённые ошибки чтения, вызываемые дислексией.",
    "Accessibility" : "Доступность",
    "Accessibility options for nextcloud" : "Настройки доступности для Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Предоставляет несколько вариантов доступности, чтобы облегчить использование Nextcloud",
    "Web Content Accessibility Guidelines" : "Руководство по обеспечению доступности Web-контента WGAG",
    "our issue tracker" : "Сообщить об ошибке",
    "our design team" : "Команда разработчиков",
    "Enable" : "Включить",
    "High contrast theme" : "Режим высокой контрастности",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Это высококонтрастное оформление упрощает навигацию по сайту. Качество изображения будет уменьшено за счёт увеличения чёткости.",
    "Dark theme (beta)" : "Тёмное оформление (бета)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic — это бесплатный шрифт, разработанный для облегчения восприятия текста людьми, которые страдают дислексией. Шрифт был создан Абелардо Гонсалесом (ориг. Abelardo Gonzalez), на правах лицензии с открытым исходным кодом (SIL Open Font License).",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Предоставляет расширенный вариант настройки nextcloud, для более комфортного использования",
    "Themes" : "Оформления",
    "Fonts" : "Шрифты",
    "enabled" : "включен"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
